@@ -7,7 +7,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.003_01';
+our $VERSION = '0.004_01';
 
 sub import {
     my ( undef, $test_class, @test_inc ) = @_;
@@ -124,7 +124,8 @@ L<Test2::V0|Test2::V0>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Test2-Tools-LoadModule/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -132,7 +133,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2020 by Thomas R. Wyant, III
+Copyright (C) 2020-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
